@@ -23,6 +23,10 @@
 
 #include "dialog_layout.h"
 #include "../utility_widgets/combo_textglade.h"
+#include "../combobox_relationship.h"
+
+namespace Glom
+{
 
 class Dialog_Layout_List_Related : public Dialog_Layout
 {
@@ -36,11 +40,11 @@ public:
    * @param table_name The table name.
    * @param table_fields: The actual fields in the table, in case the document does not yet know about them all.
    */
-  virtual void set_document(const Glib::ustring& layout, Document_Glom* document, const LayoutItem_Portal& portal);
+  virtual void set_document(const Glib::ustring& layout, Document_Glom* document, const sharedptr<const LayoutItem_Portal>& portal);
   virtual void update_ui(bool including_relationships_list = true);
 
-  virtual Glib::ustring get_relationship_name() const;
-  LayoutItem_Portal get_portal_layout();
+  sharedptr<Relationship> get_relationship() const;
+  sharedptr<LayoutItem_Portal>  get_portal_layout();
 
 protected:
 
@@ -50,15 +54,17 @@ protected:
   virtual void save_to_document();
 
   //signal handlers:
-  virtual void on_button_field_up();
-  virtual void on_button_field_down();
-  virtual void on_button_add_field();
-  virtual void on_button_delete();
-  virtual void on_button_edit_field();
-  virtual void on_button_field_formatting();
-  virtual void on_treeview_fields_selection_changed();
-  virtual void on_combo_relationship_changed();
-  virtual void on_cell_data_name(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter);
+  void on_button_field_up();
+  void on_button_field_down();
+  void on_button_add_field();
+  void on_button_delete();
+  void on_button_edit_field();
+  void on_button_field_formatting();
+  void on_treeview_fields_selection_changed();
+  void on_combo_relationship_changed();
+  void on_cell_data_name(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter);
+  
+  void Dialog_Layout_List_Related::on_combo_navigation_specific_changed();
 
   //Tree model columns:
   class ModelColumns_Fields : public Gtk::TreeModel::ColumnRecord
@@ -68,7 +74,7 @@ protected:
     ModelColumns_Fields()
     { add(m_col_layout_item); add(m_col_sequence); }
 
-    Gtk::TreeModelColumn<LayoutItem_Field> m_col_layout_item;
+    Gtk::TreeModelColumn< sharedptr<LayoutItem_Field> > m_col_layout_item;
     Gtk::TreeModelColumn<guint> m_col_sequence;
   };
 
@@ -83,10 +89,17 @@ protected:
   Gtk::Button* m_button_field_edit;
   Gtk::Button* m_button_field_formatting;
 
-  Combo_TextGlade* m_combo_relationship_name;
-  LayoutItem_Portal m_portal;
+  ComboBox_Relationship* m_combo_relationship;
+  sharedptr<LayoutItem_Portal> m_portal;
+
+  Gtk::RadioButton* m_radio_navigation_automatic;
+  Gtk::RadioButton* m_radio_navigation_specify;
+  Gtk::Label* m_label_navigation_automatic;
+  ComboBox_Relationship* m_combo_navigation_specify;
 
   Glib::RefPtr<Gtk::ListStore> m_model_fields;
 };
 
+} //namespace Glom
+
 #endif //GLOM_MODE_DATA_DIALOG_LAYOUT_LIST_RELATED_H
